@@ -1,11 +1,16 @@
 #' @rdname LambertW-utils
 #' @export
 rLambertW <- function(n, distname, theta = NULL, beta = NULL, gamma = 0, delta = 0, alpha = 1, 
-                      return.x = FALSE, input.u = NULL, tau = NULL) {
+                      return.x = FALSE, input.u = NULL, tau = NULL,
+                      use.mean.variance = TRUE) {
   
   stopifnot(n > 0)
   
   if (is.null(theta)) {
+    warning("Please specify parameters by passing a list",
+            "to the 'theta' argument directly.\n",
+            "Specifying parameters by alpha, beta, gamma, delta will be",
+            "deprecated.")
     theta <- list(beta = beta, alpha = alpha, gamma = gamma, delta = delta)
   } 
   theta <- complete_theta(theta)
@@ -13,8 +18,10 @@ rLambertW <- function(n, distname, theta = NULL, beta = NULL, gamma = 0, delta =
   if (is.null(input.u)) {
     check_distname(distname)
     check_theta(theta = theta, distname = distname)
-    tau <- theta2tau(theta = theta, distname = distname)
-    uu <- rU(n = n, beta = theta$beta, distname = distname)
+    tau <- theta2tau(theta = theta, distname = distname, 
+                     use.mean.variance = use.mean.variance)
+    uu <- rU(n = n, beta = theta$beta, distname = distname,
+             use.mean.variance = use.mean.variance)
   } else {
     if (is.numeric(input.u)) {
       uu <- input.u
